==> vue-components-1.5.13.tgz: package/lib/pickList/src/PickList.vue.rd.js <==
import { defineComponent as oe, toRefs as ae, ref as D, watch as I, onMounted as re, openBlock as s, createElementBlock as a, createElementVNode as o, normalizeClass as S, createCommentVNode as d, createVNode as h, unref as e, toDisplayString as m, isRef as E, withCtx as x, Fragment as f, renderList as L, renderSlot as _, createBlock as $ } from "vue";
import { useInfiniteScroll as ne } from "@regiondev/vue-hooks";
import { useVModels as ce, refDebounced as W } from "@vueuse/core";
import { useTransfer as N } from "./hooks/useTransfer.rd.js";
import { pickListProps as ie } from "./props.rd.js";
import "../../buttons/index.rd.js";
import R from "../../icons/states/EmptySearch.vue.rd.js";
import j from "../../icons/states/GenericEmpty.vue.rd.js";
import "../../input/index.rd.js";
import "../../spinners/index.rd.js";
import { RAntCheckbox as C } from "../../form/index.rd.js";
import M from "../../input/Input.vue.rd.js";
import de from "../../spinners/loaders/DotsSpinning.vue.rd.js";
import P from "../../buttons/src/Button.vue.rd.js";
const ue = { class: "flex flex-col md:flex-row md:max-h-300px max-h-full space-x-2" }, he = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, me = { class: "border-gray-200 border-b-solid border-1px dark:border-slate-700 border-b py-3 px-4 flex space-x-4" }, fe = { class: "mb-0 font-bold inline-flex items-center text-theme" }, pe = {
  key: 1,
  class: "px-2 py-3"
}, ve = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), ye = {
  key: 2,
  class: "w-full flex justify-center absolute-center"
}, be = ["onClick"], ge = { class: "flex items-center h-5" }, ke = {
  key: 0,
  class: "ml-3 text-sm"
}, xe = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, _e = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, Ce = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Available", -1), we = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Se = {
  key: 4,
  class: "mt-auto p-2 px-3"
}, $e = { class: "justify-center flex flex-row sm:flex-col items-baseline sm:items-center sm:space-x-0 py-4 space-x-4 space-y-3" }, Fe = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-right" }, null, -1), Ke = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-left" }, null, -1), Te = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, Ae = { class: "border-gray-200 border-b-solid border-1px dark:border-slate-700 border-b py-3 px-4 flex space-x-4" }, Ve = { class: "mb-0 font-bold inline-flex items-center text-theme" }, De = {
  key: 1,
  class: "px-2 py-3"
}, Ie = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), Ee = { class: "scrollbox m-0 p-0 relative basis-100%" }, Le = ["onClick"], We = { class: "flex items-center h-5" }, Ne = { class: "ml-3 text-sm flex items-center w-full" }, Re = {
  key: 0,
  class: "ml-3 text-sm"
}, je = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, Me = ["onClick"], Pe = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, ze = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Selected", -1), Be = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Ue = {
  key: 2,
  class: "mt-auto p-2 px-3"
}, at = /* @__PURE__ */ oe({
  __name: "PickList",
  props: ie(),
  emits: [
    "changeFilterTarget",
    "changeFilterSelected",
    "loadMore",
    "update:targetKeys"
  ],
  setup(z, { emit: w }) {
    const F = z, { targetKeys: p, selectedKeys: v } = ce(F), { idKey: r, disabledKeys: g, dataSource: k, loadingData: K } = ae(F), y = D(""), b = D(""), B = W(y, 500), U = W(b, 500);
    I(B, () => w("changeFilterTarget")), I(U, () => w("changeFilterSelected"));
    const [c, G, q, H] = N(g, p), [
      n,
      J,
      O,
      Q
    ] = N(g, v);
    re(() => {
      !p.value.length && k.value.length && (p.value = k.value.map((t) => t[r.value]));
    });
    function T(t, i) {
      t.target.checked ? n.value.push(i) : n.value = n.value.filter((u) => u !== i);
    }
    function A(t, i) {
      t.target.checked ? c.value.push(i) : c.value = c.value.filter((u) => u !== i);
    }
    function X(t) {
      t.target.checked ? c.value = Array.from(H.value) : c.value = [];
    }
    function Y(t) {
      t.target.checked ? n.value = Array.from(Q.value) : n.value = [];
    }
    function Z() {
      c.value.length && (v.value.push(...c.value), p.value = p.value.filter((t) => !c.value.includes(t)), c.value = []);
    }
    function V() {
      n.value.length && (p.value.push(...n.value), v.value = v.value.filter(
        (t) => !n.value.includes(t)
      ), n.value = []);
    }
    const { scrollElement: ee } = ne(() => w("loadMore"), { loading: K });
    function te(t) {
      n.value.push(t), V();
    }
    function le(t) {
      T({ target: { checked: !n.value.includes(t) } }, t);
    }
    function se(t) {
      A({ target: { checked: !c.value.includes(t) } }, t);
    }
    return (t, i) => (s(), a("div", ue, [
      o("div", {
        class: S([[t.cardClass], "relative dark:shadow-lg max-h-300 md:max-h-full border border-solid card min-h-300px flex flex-col w-full sm:w-1/2 !p-0 overflow-hidden"])
      }, [
        t.isDisabled ? (s(), a("div", he)) : d("", !0),
        o("div", me, [
          h(e(C), {
            indeterminate: e(G),
            checked: e(q),
            onChange: X
          }, null, 8, ["indeterminate", "checked"]),
          o("span", fe, m(e(c).length) + "/" + m(e(p).length) + " " + m(t.availableText), 1)
        ]),
        t.showFilter ? (s(), a("div", pe, [
          h(e(M), {
            modelValue: e(y),
            "onUpdate:modelValue": i[0] || (i[0] = (l) => E(y) ? y.value = l : null),
            simple: "",
            class: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: x(() => [
              ve
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        e(K) ? (s(), a("div", ye, [
          h(e(de))
        ])) : (s(), a("ul", {
          key: 3,
          ref_key: "scrollElement",
          ref: ee,
          class: "relative scrollbox basis-100% m-0 p-0"
        }, [
          (s(!0), a(f, null, L(e(k), (l) => (s(), a(f, {
            key: l[e(r)]
          }, [
            !e(v).includes(l[e(r)]) && l[t.textKey].toLowerCase().includes(e(y).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: "mb-1 items-center relative cursor-pointer px-4 py-2 flex hover:bg-primary-100 dark:hover:bg-primary-700/20",
              onClick: (u) => se(l[e(r)])
            }, [
              o("div", ge, [
                h(e(C), {
                  checked: e(c).includes(l[e(r)]),
                  disabled: e(g).includes(l[e(r)]),
                  onChange: (u) => A(u, l[e(r)])
                }, null, 8, ["checked", "disabled", "onChange"])
              ]),
              t.$slots.renderItem ? _(t.$slots, "renderItem", {
                key: 1,
                item: l
              }) : (s(), a("div", ke, [
                o("label", xe, m(l[t.textKey]), 1)
              ]))
            ], 8, be)) : d("", !0)
          ], 64))), 128)),
          o("div", _e, [
            e(y).length ? (s(), a(f, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              we
            ], 64)) : (s(), a(f, { key: 0 }, [
              h(e(R), { class: "w-80px h-auto pb-4" }),
              Ce
            ], 64))
          ])
        ], 512)),
        t.$slots.targetFooter ? (s(), a("div", Se, [
          _(t.$slots, "targetFooter")
        ])) : d("", !0)
      ], 2),
      o("div", $e, [
        h(e(P), {
          disabled: t.isDisabled || e(c).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: "flex w-auto",
          onClick: Z
        }, {
          default: x(() => [
            Fe
          ]),
          _: 1
        }, 8, ["disabled"]),
        t.oneWay ? d("", !0) : (s(), $(e(P), {
          key: 0,
          disabled: t.isDisabled || e(n).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: "flex w-auto",
          onClick: V
        }, {
          default: x(() => [
            Ke
          ]),
          _: 1
        }, 8, ["disabled"]))
      ]),
      o("div", {
        class: S([[t.cardClass], "dark:shadow-lg max-h-300 md:max-h-full border border-solid relative min-h-300px overflow-hidden card flex flex-col w-full sm:w-1/2 !p-0"])
      }, [
        t.isDisabled ? (s(), a("div", Te)) : d("", !0),
        o("div", Ae, [
          t.oneWay ? d("", !0) : (s(), $(e(C), {
            key: 0,
            indeterminate: e(J),
            checked: e(O),
            onChange: Y
          }, null, 8, ["indeterminate", "checked"])),
          o("span", Ve, m(e(n).length) + "/" + m(e(v).length) + " " + m(t.selectedText), 1)
        ]),
        t.showFilter ? (s(), a("div", De, [
          h(e(M), {
            modelValue: e(b),
            "onUpdate:modelValue": i[1] || (i[1] = (l) => E(b) ? b.value = l : null),
            simple: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: x(() => [
              Ie
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        o("ul", Ee, [
          (s(!0), a(f, null, L(e(k), (l) => (s(), a(f, {
            key: l[e(r)]
          }, [
            e(v).includes(l[e(r)]) && l[t.textKey].toLowerCase().includes(e(b).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: S(["mb-1 relative px-4 py-2 flex items-center", {
                "hover:bg-primary-100 cursor-pointer dark:hover:bg-primary-700/20": !t.oneWay
              }]),
              onClick: (u) => !t.oneWay && le(l[e(r)])
            }, [
              o("div", We, [
                t.oneWay ? d("", !0) : (s(), $(e(C), {
                  key: 0,
                  disabled: e(g).includes(l[e(r)]),
                  checked: e(n).includes(l[e(r)]),
                  onChange: (u) => T(u, l[e(r)])
                }, null, 8, ["disabled", "checked", "onChange"]))
              ]),
              o("div", Ne, [
                t.$slots.renderItem ? _(t.$slots, "renderItem", {
                  key: 1,
                  item: l
                }) : (s(), a("div", Re, [
                  o("label", je, m(l[t.textKey]), 1)
                ])),
                t.oneWay ? (s(), a("span", {
                  key: 2,
                  class: "dark:text-red-400 dark:hover:text-red-300 ml-auto text-red-300 cursor-pointer hover:text-red-500 text-lg i-heroicons-outline:trash",
                  onClick: (u) => te(l[e(r)])
                }, null, 8, Me)) : d("", !0)
              ])
            ], 10, Le)) : d("", !0)
          ], 64))), 128)),
          o("div", Pe, [
            e(b).length ? (s(), a(f, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              Be
            ], 64)) : (s(), a(f, { key: 0 }, [
              h(e(R), { class: "w-80px h-auto pb-4" }),
              ze
            ], 64))
          ])
        ]),
        t.$slots.selectedFooter ? (s(), a("div", Ue, [
          _(t.$slots, "selectedFooter")
        ])) : d("", !0)
      ], 2)
    ]));
  }
});
export {
  at as default
};

==> vue-components-1.5.40.tgz: package/lib/pickList/src/PickList.vue.rd.js <==
import { defineComponent as oe, toRefs as ae, ref as D, watch as I, onMounted as re, openBlock as s, createElementBlock as a, createElementVNode as o, normalizeClass as S, createCommentVNode as d, createVNode as h, unref as e, toDisplayString as m, isRef as E, withCtx as x, Fragment as f, renderList as L, renderSlot as _, createBlock as $ } from "vue";
import { useInfiniteScroll as ne } from "@regiondev/vue-hooks";
import { useVModels as ce, refDebounced as W } from "@vueuse/core";
import { useTransfer as N } from "./hooks/useTransfer.rd.js";
import { pickListProps as ie } from "./props.rd.js";
import "../../buttons/index.rd.js";
import R from "../../icons/states/EmptySearch.vue.rd.js";
import j from "../../icons/states/GenericEmpty.vue.rd.js";
import "../../input/index.rd.js";
import "../../spinners/index.rd.js";
import { RAntCheckbox as C } from "../../form/index.rd.js";
import M from "../../input/Input.vue.rd.js";
import de from "../../spinners/loaders/DotsSpinning.vue.rd.js";
import P from "../../buttons/src/Button.vue.rd.js";
const ue = { class: "flex flex-col md:flex-row md:max-h-300px max-h-full space-x-2" }, he = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, me = { class: "border-gray-200 border-b-solid border-1px dark:border-slate-700 border-b py-3 px-4 flex space-x-4" }, fe = { class: "mb-0 font-bold inline-flex items-center text-theme" }, pe = {
  key: 1,
  class: "px-2 py-3"
}, ve = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), ye = {
  key: 2,
  class: "w-full flex justify-center absolute-center"
}, be = ["onClick"], ge = { class: "flex items-center h-5" }, ke = {
  key: 0,
  class: "ml-3 text-sm"
}, xe = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, _e = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, Ce = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Available", -1), we = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Se = {
  key: 4,
  class: "mt-auto p-2 px-3"
}, $e = { class: "justify-center flex flex-row sm:flex-col items-baseline sm:items-center sm:space-x-0 py-4 space-x-4 space-y-3" }, Fe = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-right" }, null, -1), Ke = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-left" }, null, -1), Te = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, Ae = { class: "border-gray-200 border-b-solid border-b-1px dark:border-slate-700 border-b py-3 px-4 flex space-x-4" }, Ve = { class: "mb-0 font-bold inline-flex items-center text-theme" }, De = {
  key: 1,
  class: "px-2 py-3"
}, Ie = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), Ee = { class: "scrollbox m-0 p-0 relative basis-100%" }, Le = ["onClick"], We = { class: "flex items-center h-5" }, Ne = { class: "ml-3 text-sm flex items-center w-full" }, Re = {
  key: 0,
  class: "ml-3 text-sm"
}, je = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, Me = ["onClick"], Pe = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, ze = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Selected", -1), Be = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Ue = {
  key: 2,
  class: "mt-auto p-2 px-3"
}, at = /* @__PURE__ */ oe({
  __name: "PickList",
  props: ie(),
  emits: [
    "changeFilterTarget",
    "changeFilterSelected",
    "loadMore",
    "update:targetKeys"
  ],
  setup(z, { emit: w }) {
    const F = z, { targetKeys: p, selectedKeys: v } = ce(F), { idKey: r, disabledKeys: g, dataSource: k, loadingData: K } = ae(F), y = D(""), b = D(""), B = W(y, 500), U = W(b, 500);
    I(B, () => w("changeFilterTarget")), I(U, () => w("changeFilterSelected"));
    const [c, G, q, H] = N(g, p), [
      n,
      J,
      O,
      Q
    ] = N(g, v);
    re(() => {
      !p.value.length && k.value.length && (p.value = k.value.map((t) => t[r.value]));
    });
    function T(t, i) {
      t.target.checked ? n.value.push(i) : n.value = n.value.filter((u) => u !== i);
    }
    function A(t, i) {
      t.target.checked ? c.value.push(i) : c.value = c.value.filter((u) => u !== i);
    }
    function X(t) {
      t.target.checked ? c.value = Array.from(H.value) : c.value = [];
    }
    function Y(t) {
      t.target.checked ? n.value = Array.from(Q.value) : n.value = [];
    }
    function Z() {
      c.value.length && (v.value.push(...c.value), p.value = p.value.filter((t) => !c.value.includes(t)), c.value = []);
    }
    function V() {
      n.value.length && (p.value.push(...n.value), v.value = v.value.filter(
        (t) => !n.value.includes(t)
      ), n.value = []);
    }
    const { scrollElement: ee } = ne(() => w("loadMore"), { loading: K });
    function te(t) {
      n.value.push(t), V();
    }
    function le(t) {
      T({ target: { checked: !n.value.includes(t) } }, t);
    }
    function se(t) {
      A({ target: { checked: !c.value.includes(t) } }, t);
    }
    return (t, i) => (s(), a("div", ue, [
      o("div", {
        class: S([[t.cardClass], "relative dark:shadow-lg max-h-300 md:max-h-full border border-solid card min-h-300px flex flex-col w-full sm:w-1/2 !p-0 overflow-hidden"])
      }, [
        t.isDisabled ? (s(), a("div", he)) : d("", !0),
        o("div", me, [
          h(e(C), {
            indeterminate: e(G),
            checked: e(q),
            onChange: X
          }, null, 8, ["indeterminate", "checked"]),
          o("span", fe, m(e(c).length) + "/" + m(e(p).length) + " " + m(t.availableText), 1)
        ]),
        t.showFilter ? (s(), a("div", pe, [
          h(e(M), {
            modelValue: e(y),
            "onUpdate:modelValue": i[0] || (i[0] = (l) => E(y) ? y.value = l : null),
            simple: "",
            class: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: x(() => [
              ve
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        e(K) ? (s(), a("div", ye, [
          h(e(de))
        ])) : (s(), a("ul", {
          key: 3,
          ref_key: "scrollElement",
          ref: ee,
          class: "relative scrollbox basis-100% m-0 p-0"
        }, [
          (s(!0), a(f, null, L(e(k), (l) => (s(), a(f, {
            key: l[e(r)]
          }, [
            !e(v).includes(l[e(r)]) && l[t.textKey].toLowerCase().includes(e(y).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: "mb-1 items-center relative cursor-pointer px-4 py-2 flex hover:bg-primary-100 dark:hover:bg-primary-700/20",
              onClick: (u) => se(l[e(r)])
            }, [
              o("div", ge, [
                h(e(C), {
                  checked: e(c).includes(l[e(r)]),
                  disabled: e(g).includes(l[e(r)]),
                  onChange: (u) => A(u, l[e(r)])
                }, null, 8, ["checked", "disabled", "onChange"])
              ]),
              t.$slots.renderItem ? _(t.$slots, "renderItem", {
                key: 1,
                item: l
              }) : (s(), a("div", ke, [
                o("label", xe, m(l[t.textKey]), 1)
              ]))
            ], 8, be)) : d("", !0)
          ], 64))), 128)),
          o("div", _e, [
            e(y).length ? (s(), a(f, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              we
            ], 64)) : (s(), a(f, { key: 0 }, [
              h(e(R), { class: "w-80px h-auto pb-4" }),
              Ce
            ], 64))
          ])
        ], 512)),
        t.$slots.targetFooter ? (s(), a("div", Se, [
          _(t.$slots, "targetFooter")
        ])) : d("", !0)
      ], 2),
      o("div", $e, [
        h(e(P), {
          disabled: t.isDisabled || e(c).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: "flex",
          onClick: Z
        }, {
          default: x(() => [
            Fe
          ]),
          _: 1
        }, 8, ["disabled"]),
        t.oneWay ? d("", !0) : (s(), $(e(P), {
          key: 0,
          disabled: t.isDisabled || e(n).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: "flex",
          onClick: V
        }, {
          default: x(() => [
            Ke
          ]),
          _: 1
        }, 8, ["disabled"]))
      ]),
      o("div", {
        class: S([[t.cardClass], "dark:shadow-lg max-h-300 md:max-h-full border border-solid relative min-h-300px overflow-hidden card flex flex-col w-full sm:w-1/2 !p-0"])
      }, [
        t.isDisabled ? (s(), a("div", Te)) : d("", !0),
        o("div", Ae, [
          t.oneWay ? d("", !0) : (s(), $(e(C), {
            key: 0,
            indeterminate: e(J),
            checked: e(O),
            onChange: Y
          }, null, 8, ["indeterminate", "checked"])),
          o("span", Ve, m(e(n).length) + "/" + m(e(v).length) + " " + m(t.selectedText), 1)
        ]),
        t.showFilter ? (s(), a("div", De, [
          h(e(M), {
            modelValue: e(b),
            "onUpdate:modelValue": i[1] || (i[1] = (l) => E(b) ? b.value = l : null),
            simple: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: x(() => [
              Ie
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        o("ul", Ee, [
          (s(!0), a(f, null, L(e(k), (l) => (s(), a(f, {
            key: l[e(r)]
          }, [
            e(v).includes(l[e(r)]) && l[t.textKey].toLowerCase().includes(e(b).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: S(["mb-1 relative px-4 py-2 flex items-center", {
                "hover:bg-primary-100 cursor-pointer dark:hover:bg-primary-700/20": !t.oneWay
              }]),
              onClick: (u) => !t.oneWay && le(l[e(r)])
            }, [
              o("div", We, [
                t.oneWay ? d("", !0) : (s(), $(e(C), {
                  key: 0,
                  disabled: e(g).includes(l[e(r)]),
                  checked: e(n).includes(l[e(r)]),
                  onChange: (u) => T(u, l[e(r)])
                }, null, 8, ["disabled", "checked", "onChange"]))
              ]),
              o("div", Ne, [
                t.$slots.renderItem ? _(t.$slots, "renderItem", {
                  key: 1,
                  item: l
                }) : (s(), a("div", Re, [
                  o("label", je, m(l[t.textKey]), 1)
                ])),
                t.oneWay ? (s(), a("span", {
                  key: 2,
                  class: "dark:text-red-400 dark:hover:text-red-300 ml-auto text-red-300 cursor-pointer hover:text-red-500 text-lg i-heroicons-outline:trash",
                  onClick: (u) => te(l[e(r)])
                }, null, 8, Me)) : d("", !0)
              ])
            ], 10, Le)) : d("", !0)
          ], 64))), 128)),
          o("div", Pe, [
            e(b).length ? (s(), a(f, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              Be
            ], 64)) : (s(), a(f, { key: 0 }, [
              h(e(R), { class: "w-80px h-auto pb-4" }),
              ze
            ], 64))
          ])
        ]),
        t.$slots.selectedFooter ? (s(), a("div", Ue, [
          _(t.$slots, "selectedFooter")
        ])) : d("", !0)
      ], 2)
    ]));
  }
});
export {
  at as default
};
